@@ -1,9 +1,12 @@
 """Spy call verification."""
 from typing import Optional, Sequence
 
-from .spy_calls import SpyCall, VerifyRehearsal
+from .spy_calls import SpyCall, VerifyRehearsal, match_call
 from .errors import VerifyError
 
+# ensure decoy.verifier does not pollute Pytest tracebacks
+__tracebackhide__ = True
+
 
 class Verifier:
     """An interface to verify that spies were called as expected."""
@@ -30,8 +33,9 @@ class Verifier:
 
         for i in range(len(calls)):
             calls_subset = calls[i : i + len(rehearsals)]
+            matches = [match_call(c, r) for c, r in zip(calls_subset, rehearsals)]
 
-            if calls_subset == rehearsals:
+            if all(matches) and len(calls_subset) == len(rehearsals):
                 match_count = match_count + 1
 
         calls_verified = match_count != 0 if times is None else match_count == times
